==> flatnuke_2.7.orig.tar.gz: flatnuke-2.7/languages/fd+lang/fd+pt.php <==
<?
/**
 * FD+:Portuguese Translation
 * @author Paulo Silva <correasilva_at_tugamail_dot_pt>
 */

//User interface
define("_FDNAME","Nome");
define("_FDSIZE","Tamanho");
define("_FDDATE","Release&nbsp;Date");
define("_FDVERSION", "Verso");
define("_FDDESC","Descrio");
define("_FDHITS","Hits");
define("_FDDOWNLOAD","DOWNLOAD!");
define("_FDSTAT","Descarregar Estatsticas");
define("_FDSTATTITLE","Ver estatsticas de downloads");
define("_FDDOWNLOADFILE","Descarregar o ficheiro: ");
define("_FDARCHIVEDIR","Directrio de arquivo");
/*define("_GOTOSECTION","Go to the section");*/
define("_FDUPLOADER","Enviado por");
define("_FDUPLOADERTITLE","Ver perfil do utilizador");
//Date format
define("_FDDATEFORMAT","m/d/Y H:i:s");

//gpg sign
define("_FDGPGSIGN","assinatura gpg");
define("_FDGPGSIGNTITLE","Descarregar assinatura gpg do ficheiro: ");
define("_FDDELETESIG","Apagar assinatura");

//Admin
define("_FDARCHIVE","Arquivo");
define("_FDRESTORE","Recuperar");
define("_FDEDIT","Editar");
define("_FDDELETE","Apagar");
define("_FDHIDE","Esconder");
define("_FDSHOW","Mostrar");
define("_FDRENAME","Renomear");
define("_FDADDFILE","Adiconar ficheiro");
define("_FDARCHIVETITLE","Arquivar o ficheiro: ");
define("_FDRESTORETITLE","Recuperar o ficheiro: ");
define("_FDEDITTITLE","Editar o ttulo para o ficheiro: ");
define("_FDDELETETITLE","Apagar o ficheiro: ");
define("_FDHIDETITLE","Esconder o ficheiro: ");
define("_FDSHOWTITLE","Fazer visvel o ficheiro: ");
define("_FDRENAMETITLE","Renomear o ficheiro: ");
define("_FDADDFILETITLE","Adicionar ficheiro nesta seco.");
define("_FDBACK","Trs");

//Edit/Add file
define("_FDRETURN","Retornar");
define("_FDEDITDESC","Editar descrio do ficheiro: ");
define("_FDEDITHEADER","Nesta pgina pode editar a descrio do ficheiro gerido por FlatDownloadPlus. As mudanas sero gravadas no ficheiro: ");
define("_FDEDITFOOTER","Pode tambm mudar o ficheiro em si.<br />O novo ficheiro pode ter um nome diferente. Se o novo nome  diferente, fd+ mudar a correspondente \".descrio\".<br /> O ficheiro antigo ser apagado.");
define("_FDEDITSAVE", "Gravar mudanas");
define("_FDEDITDONE", "Mudanas aplicadas");

//Rename File
define("_FDRENAMECHOOSE","Escolher um novo nome: ");
define("_FDRENAMEEXTLIMIT","No  possvel editar a extenso do ficheiro.");
define("_FDRENAMEFILE","O ficheiro ");
define("_FDRENAMENOFD","no  um ficheiro FD+.");
define("_FDRENAMEOK","Ficheiro renomeado com sucesso.");
define("_FDRENAMENOTCHANGED","Nome do ficheiro no foi mudado.");
define("_FDRENAMEEXISTS1","J existe ficheiro chamado");
define("_FDRENAMEEXISTS2","no directrio");
define("_FDRENAMECHANGENAME","Escolhe outro nome.");
define("_FDRENAMEALERT","<b>Ateno!</b> O ficheiro no pde ser renomeado");

//Delete file
define("_FDDELSURE","Tem certeza que quer apagar o ficheiro: ");
define("_FDDEL", "Apagar");
define("_FDCANC", "Cancelar");
define("_FDDELOK","Ficheiros apagados: ");
define("_FDAND","and");

//Archive file
define("_FDARCHIVEOK","Ficheiro arquivado.");
define("_FDARCHIVEGO","Ir para o directrio de arquivo.");
define("_FDRESTOREOK","O ficheiro foi recuperado com sucesso");
define("_FDARCHIVERETURN","retornar para a seco anterior");
define("_GOTOARCHIVEDIR","Ir para a seco de arquivo");

//Add file
define("_FDADDWHERE","Adicionar novo ficheiro na directoria: ");
define("_FDADDHEADER","Aqui pode adicionar outro ficheiro para a pasta corrente");
define("_FDADDFOOTER","Escolhe um ficheiro no seu disco rigido.");
define("_NOTVALIDEXT","A extenso deste ficheiro no  suportada por FD+. Adicionar esta extenso na varivel &#036;extenses do ficheiro \"fd+.php\"");

//save file
define("_FDSAVESIZE","<b>Ateno!</b> O tamanho do ficheiro  ");

//move file
define("_FDMOVE","Mover");
define("_FDMOVEFILE","Mover o ficheiro ");
define("_FDMOVEFILESECTION"," para a seco");
define("_FDMOVELINK","(clicar no link para mover)");
define("_FDMOVECONFIRM","Mover o ficheiro ");
define("_FDMOVEFAIL","No  possvel mover o ficheiro ");
define("_FDMOVESUCCESS","movido com sucesso");
define("_FDMOVETITLE","Mover o ficheiro: ");
define("_FDDIR","O directrio");

//creazione cartelle
define("_FDCREATESECTDOWNLOAD","Seco de Download criada");
define("_FDCREATESECT","Criar seco");
define("_FDCREATESECTOK","criado com sucesso!");
define("_FDCREATEONLYDIR","Seco criada, mas no foi possivel criar o ficheiro section.php");
define("_FDCREATEDIRERROR","<b>Ateno!</b>: No pde ser criada a seco: ");
define("_FDCHECKPERM","Verificar permisses de escrita.");
define("_FDHIDDENSECT","esconder seco");
define("_FDCHOOSESECTNAME","Escolher o nome da seco:");
define("_FDCREATESUBSECT","Criar uma seco em: ");
define("_FDNOTWRITE","is not writeable!");

//upload file
define("_FDTOOBIG","<b>Ateno!</b><br />Este ficheiro no pode ser enviado para o servidor por ser muito grande.");
define("_FDUPLOADOK","Ficheiro enviado com sucesso.");
define("_FDUPLOADEXISTS","<b>Ateno!</b> Na directoria seleccionada esiste um ficheiro com o mesmo nome. <br /> Se quer modificar este ficheiro ou a descrio relacionada, usa a funo <b>Editar</b>.");
define("_FDFILENOTSELECT","Seleccione um ficheiro!");

//Alert
define("_FDDESCTOOLONG","<b>Ateno!</b> a descrio  muito longa.");
define("_FDNAMETOOLONG","<b>Ateno!</b> o ttulo  muito longo.");
define("_FDREDONLYDIR","<b>Ateno:</b> verificar permisso de escrita nesta directoria.");
define("_FDERROR","<B>Erro!</B>");

//error
define("_FDNONPUOI","<b>You may not do that!</b> (erro de segurana.)<br /> FDPlus: linha ");
define("_FDERROR1","O ficheiro enviado excede o upload_max_filesize directive in php.ini.");
define("_FDERROR2","O ficheiro enviado excede o MAX_FILE_SIZE directive que foi especificado no formulrio HTML.");
define("_FDERROR3","O ficheiro enviado o foi apenas parcialmente.");
define("_FDERROR4","Nenhum ficheiro foi enviado.");
define("_FDERROR6","Falta pasta temporria.");
define("_FDERROR7","A escrita do ficheiro no disco falhou.");

//DOWNLOAD STATS
define("_FDSECT","Section");
define("_FDTOPSTATS", "Descarregar&nbsp;Estatsticas");
//TOP DOWNLOAD
define("_FDTOPSTAT","Estatsticas");

?>

==> flatnuke_2.7.2.orig.tar.gz: flatnuke-2.7.2/languages/fd+lang/fd+pt.php <==
<?
/**
 * FD+:Portuguese Translation
 * @author Paulo Silva <correasilva_at_tugamail_dot_pt>
 */

//User interface
define("_FDNAME","Nome");
define("_FDSIZE","Tamanho");
define("_FDDATE","Date");
define("_FDVERSION", "Verso");
define("_FDDESC","Descrio");
define("_FDHITS","Hits");
define("_FDDOWNLOAD","DOWNLOAD!");
define("_FDSTAT","Descarregar Estatsticas");
define("_FDSTATTITLE","Ver estatsticas de downloads");
define("_FDDOWNLOADFILE","Descarregar o ficheiro: ");
define("_FDARCHIVEDIR","Directrio de arquivo");
/*define("_GOTOSECTION","Go to the section");*/
define("_FDUPLOADER","Enviado por");
define("_FDUPLOADERTITLE","Ver perfil do utilizador");
define("_FDSUMMARY","Summary");//need translation
define("_FDSUBDIRS","Subsections");//need translation
define("_FDRATING","Rating");//need translation
define("_FDRATEFILE","Rate this file");//need translation
define("_FDALREADYRATED","You have already rated this file!");//need translation
define("_FDVOTES","votes");//need translation
define("_FDTOVOTEAFILE","to vote a file");//need translation
define("_ENABLEVOTE","Enable vote");//need translation
//Date format
define("_FDDATEFORMAT","m/d/Y H:i:s");

//gpg sign
define("_FDGPGSIGN","assinatura gpg");
define("_FDGPGSIGNTITLE","Descarregar assinatura gpg do ficheiro: ");
define("_FDDELETESIG","Apagar assinatura");

//Admin
define("_FDARCHIVE","Arquivo");
define("_FDRESTORE","Recuperar");
define("_FDEDIT","Editar");
define("_FDDELETE","Apagar");
define("_FDHIDE","Esconder");
define("_FDSHOW","Mostrar");
define("_FDRENAME","Renomear");
define("_FDADDFILE","Adiconar ficheiro");
define("_FDARCHIVETITLE","Arquivar o ficheiro: ");
define("_FDRESTORETITLE","Recuperar o ficheiro: ");
define("_FDEDITTITLE","Editar o ttulo para o ficheiro: ");
define("_FDDELETETITLE","Apagar o ficheiro: ");
define("_FDHIDETITLE","Esconder o ficheiro: ");
define("_FDSHOWTITLE","Fazer visvel o ficheiro: ");
define("_FDRENAMETITLE","Renomear o ficheiro: ");
define("_FDADDFILETITLE","Adicionar ficheiro nesta seco.");
define("_FADMINPANEL","Admin panel");//need translation
define("_FDALLOWUSERUPLOAD","Allow users to propose files in this section");//need translation

define("_FDBACK","Trs");

//Edit/Add file
define("_FDRETURN","Retornar");
define("_FDEDITDESC","Editar descrio do ficheiro: ");
define("_FDEDITHEADER","Nesta pgina pode editar a descrio do ficheiro gerido por FlatDownloadPlus. As mudanas sero gravadas no ficheiro: ");
define("_FDEDITFOOTER","Pode tambm mudar o ficheiro em si.<br />O novo ficheiro pode ter um nome diferente. Se o novo nome  diferente, fd+ mudar a correspondente \".descrio\".<br /> O ficheiro antigo ser apagado.");
define("_FDEDITSAVE", "Gravar mudanas");
define("_FDEDITDONE", "Mudanas aplicadas");
define("_FDBASIC","Basic");//need translation
define("_FDADVANCED","Advanced");//need translation


//Rename File
define("_FDRENAMECHOOSE","Escolher um novo nome: ");
define("_FDRENAMEEXTLIMIT","No  possvel editar a extenso do ficheiro.");
define("_FDRENAMEFILE","O ficheiro ");
define("_FDRENAMENOFD","no  um ficheiro FD+.");
define("_FDRENAMEOK","Ficheiro renomeado com sucesso.");
define("_FDRENAMENOTCHANGED","Nome do ficheiro no foi mudado.");
define("_FDRENAMEEXISTS1","J existe ficheiro chamado");
define("_FDRENAMEEXISTS2","no directrio");
define("_FDRENAMECHANGENAME","Escolhe outro nome.");
define("_FDRENAMEALERT","<b>Ateno!</b> O ficheiro no pde ser renomeado");

//Delete file
define("_FDDELSURE","Tem certeza que quer apagar o ficheiro: ");
define("_FDDEL", "Apagar");
define("_FDCANC", "Cancelar");
define("_FDDELOK","Ficheiros apagados: ");
define("_FDAND","and");

//Archive file
define("_FDARCHIVEOK","Ficheiro arquivado.");
define("_FDARCHIVEGO","Ir para o directrio de arquivo.");
define("_FDRESTOREOK","O ficheiro foi recuperado com sucesso");
define("_FDARCHIVERETURN","retornar para a seco anterior");
define("_GOTOARCHIVEDIR","Ir para a seco de arquivo");

//Add file
define("_FDADDWHERE","Adicionar novo ficheiro na directoria: ");
define("_FDADDHEADER","Aqui pode adicionar outro ficheiro para a pasta corrente");
define("_FDADDFOOTER","Escolhe um ficheiro no seu disco rigido.");
define("_NOTVALIDEXT","A extenso deste ficheiro no  suportada por FD+. Adicionar esta extenso na varivel &#036;extenses do ficheiro \"fd+.php\"");

//save file
define("_FDSAVESIZE","<b>Ateno!</b> O tamanho do ficheiro  ");

//move file
define("_FDMOVE","Mover");
define("_FDMOVEFILE","Mover o ficheiro ");
define("_FDMOVEFILESECTION"," para a seco");
define("_FDMOVELINK","(clicar no link para mover)");
define("_FDMOVECONFIRM","Mover o ficheiro ");
define("_FDMOVEFAIL","No  possvel mover o ficheiro ");
define("_FDMOVESUCCESS","movido com sucesso");
define("_FDMOVETITLE","Mover o ficheiro: ");
define("_FDDIR","O directrio");

//creazione cartelle
define("_FDCREATESECTDOWNLOAD","Seco de Download criada");
define("_FDCREATESECT","Criar seco");
define("_FDCREATESECTOK","criado com sucesso!");
define("_FDCREATEONLYDIR","Seco criada, mas no foi possivel criar o ficheiro section.php");
define("_FDCREATEDIRERROR","<b>Ateno!</b>: No pde ser criada a seco: ");
define("_FDCHECKPERM","Verificar permisses de escrita.");
define("_FDHIDDENSECT","esconder seco");
define("_FDCHOOSESECTNAME","Escolher o nome da seco:");
define("_FDCREATESUBSECT","Criar uma seco em: ");
define("_FDNOTWRITE","is not writeable!");

//upload file
define("_FDTOOBIG","<b>Ateno!</b><br />Este ficheiro no pode ser enviado para o servidor por ser muito grande.");
define("_FDUPLOADOK","Ficheiro enviado com sucesso.");
define("_FDUPLOADEXISTS","<b>Ateno!</b> Na directoria seleccionada esiste um ficheiro com o mesmo nome. <br /> Se quer modificar este ficheiro ou a descrio relacionada, usa a funo <b>Editar</b>.");
define("_FDFILENOTSELECT","Seleccione um ficheiro!");

//Alert
define("_FDDESCTOOLONG","<b>Ateno!</b> a descrio  muito longa.");
define("_FDNAMETOOLONG","<b>Ateno!</b> o ttulo  muito longo.");
define("_FDREDONLYDIR","<b>Ateno:</b> verificar permisso de escrita nesta directoria.");
define("_FDERROR","<B>Erro!</B>");

//error
define("_FDNONPUOI","<b>You may not do that!</b> (erro de segurana.)<br /> FDPlus: linha ");
define("_FDERROR1","O ficheiro enviado excede o upload_max_filesize directive in php.ini.");
define("_FDERROR2","O ficheiro enviado excede o MAX_FILE_SIZE directive que foi especificado no formulrio HTML.");
define("_FDERROR3","O ficheiro enviado o foi apenas parcialmente.");
define("_FDERROR4","Nenhum ficheiro foi enviado.");
define("_FDERROR6","Falta pasta temporria.");
define("_FDERROR7","A escrita do ficheiro no disco falhou.");

//DOWNLOAD STATS
define("_FDSECT","Section");
define("_FDTOPSTATS", "Descarregar&nbsp;Estatsticas");
//TOP DOWNLOAD
define("_FDTOPSTAT","Estatsticas");


//remote file/url
define("_FDADDURL","Add remote file");
define("_FDCHOOSEURL","Specify the url of the file:");

//FDuser
define("_FDWAITFORADMIN","The file will not be immediately visible. Wait for site's administrator approval.");//need translation
define("_FDLIMIT","Raggiunto il limite massimo di file proponibili.<br> Attendi che l'amministratore pubblichi i file in attesa di approvazione."); //need translation
define("_FDPUBLISHFILES","Publish files");//need translation
define("_FDPROPOSE","Propose a file");//need translation
define("_FDWAITINGFILES","files waiting validation");//need translation

?>
